@@ -710,7 +710,7 @@ start_server {tags {"dual-channel-replication external:skip"}} {
             # 5. Replica resumes operation.
             # Expected outcome: Primary maintains RDB channel until replica establishes PSYNC connection.
             $replica replicaof $primary_host $primary_port
-            wait_for_log_messages 0 {"*Done loading RDB*"} $loglines 2000 1
+            wait_for_log_messages 0 {"*Done loading RDB*"} $loglines 2000 5
             pause_process $replica_pid
             wait_and_resume_process -1
             wait_for_condition 50 100 {
@@ -1358,3 +1358,70 @@ start_server {tags {"dual-channel-replication external:skip"}} {
         }
     }
 }
+
+# Test Sequence:
+# 1. replica -> primary.
+# 2. Replica initiates synchronization via RDB channel.
+# 3. Primary's main process is suspended.
+# 4. Replica completes RDB loading and pauses before establishing PSYNC connection.
+# 5. Primary resumes operation and detects closed RDB channel.
+# 6. Primary protects the RDB channel, maintains the RDB channel.
+# 7. replica -> primary -> new_primary
+# 8. Starting a new server, set up a chained replica.
+# 9. The primary completes sync from the new_primary server and disconnects all replica
+#    clients (including the RDB channel).
+# 10. Make sure that the primary does not assert.
+# 11. Replica resumes operation, check the replication is working correctly.
+test "Chained replicas can disconnect protected RDB channel client when using dual channel replication" {
+    start_server {tags {"dual-channel-replication external:skip"}} {
+        set primary [srv 0 client]
+        set primary_host [srv 0 host]
+        set primary_port [srv 0 port]
+
+        $primary config set repl-diskless-sync yes
+        $primary config set dual-channel-replication-enabled yes
+        $primary debug pause-after-fork 1
+        $primary debug delay-rdb-client-free-seconds 60
+
+        start_server {} {
+            set replica [srv 0 client]
+            set replica_pid [srv 0 pid]
+
+            $replica config set dual-channel-replication-enabled yes
+
+            # The primary will protect the replica's RDB channel.
+            set loglines [count_log_lines 0]
+            $replica replicaof $primary_host $primary_port
+            wait_for_log_messages 0 {"*Done loading RDB*"} $loglines 1000 50
+            pause_process $replica_pid
+            wait_and_resume_process -1
+            $primary debug pause-after-fork 0
+            wait_for_condition 1000 50 {
+                [string match {*replicas_waiting_psync:1*} [$primary info replication]]
+            } else {
+                fail "Primary freed RDB client before psync was established"
+            }
+
+            start_server {} {
+                set new_primary [srv 0 client]
+                set new_primary_host [srv 0 host]
+                set new_primary_port [srv 0 port]
+
+                # Doing the chained replica, make sure it won't assert.
+                set loglines [count_log_lines -2]
+                $primary replicaof $new_primary_host $new_primary_port
+                wait_for_log_messages -2 {"*Done loading RDB*"} $loglines 1000 50
+
+                # Check the replication is working correctly.
+                resume_process $replica_pid
+                $new_primary set foo bar
+                wait_for_condition 1000 50 {
+                    [$primary get foo] eq "bar" &&
+                    [$replica get foo] eq "bar"
+                } else {
+                    fail "Chained replicas did not sync"
+                }
+            }
+        }
+    }
+}
