@@ -484,7 +484,7 @@ start_server {} {
         r debug replybuffer resizing 1
 
         foreach rr $rrs {$rr close}
-    } {} {needs:debug}
+    } {} {needs:debug tls:skip}
 }
 
 start_server {} {
@@ -551,7 +551,7 @@ start_server {} {
         r debug replybuffer resizing 1
 
         foreach rr $rrs {$rr close}
-    } {} {needs:debug}
+    } {} {needs:debug tls:skip}
 }
 
 start_server {} {
