@@ -949,10 +949,27 @@ start_server {tags {"expire"}} {
             fail "Keys did not actively expire."
         }
     }
+
+    test {Negative ttl will not cause server to crash when import mode is on} {
+        r flushall
+        r config set import-mode yes
+        r set foo bar
+        r expireat foo -1
+        r set foo1 bar
+        r expireat foo1 -10000
+        assert_equal [r dbsize] 2
+        r config set import-mode no
+        wait_for_condition 30 100 {
+            [r dbsize] == 0
+        } else {
+            fail "key wasn't expired"
+        }
+    }
 }
 
 start_server {tags {expire} overrides {hz 100}} {
     test {Active expiration triggers hashtable shrink} {
+        r debug SET-ACTIVE-EXPIRE 0
         set persistent_keys 5
         set volatile_keys 100
         set total_keys [expr $persistent_keys + $volatile_keys]
@@ -969,6 +986,7 @@ start_server {tags {expire} overrides {hz 100}} {
         assert_equal $total_keys [r dbsize]
 
         # Wait for active expiration
+        r debug SET-ACTIVE-EXPIRE 1
         wait_for_condition 100 50 {
             [r dbsize] eq $persistent_keys
         } else {
